pub struct DescriptorBindings<'a> { /* private fields */ }Expand description
The DescriptorBindings struct provides invocation-scoped host resources to a compiled BESL program.
Implementations
Sourceimpl<'a> DescriptorBindings<'a>
impl<'a> DescriptorBindings<'a>
pub fn new() -> Self
pub fn bind_buffer(&mut self, slot: ResourceSlot, buffer: &'a mut Buffer)
pub fn bind_texture(&mut self, slot: ResourceSlot, texture: &'a mut Texture)
pub fn bind_image(&mut self, slot: ResourceSlot, image: &'a mut Texture)
pub fn bind_push_constant(&mut self, push_constant: &'a mut Buffer)
Sourcepub fn bind_mesh_outputs(&mut self, mesh_outputs: &'a mut MeshOutputs)
pub fn bind_mesh_outputs(&mut self, mesh_outputs: &'a mut MeshOutputs)
Binds the capture used by mesh output-count, position, and triangle intrinsics.
Sourcepub fn bind_task_outputs(&mut self, task_outputs: &'a mut TaskOutputs)
pub fn bind_task_outputs(&mut self, task_outputs: &'a mut TaskOutputs)
Binds the capture used by task payload writes and the task mesh-output-count intrinsic.
Sourcepub fn bind_workgroup_state(&mut self, workgroup_state: &'a mut WorkgroupState)
pub fn bind_workgroup_state(&mut self, workgroup_state: &'a mut WorkgroupState)
Binds shared storage for task fixtures executed through the workgroup scheduler.
Sourcepub fn bind_task_payload(
&mut self,
name: impl Into<String>,
values: impl IntoIterator<Item = Value>,
)
pub fn bind_task_payload( &mut self, name: impl Into<String>, values: impl IntoIterator<Item = Value>, )
Binds the authored values produced for one named task-payload array before a mesh-stage invocation.
Values are copied into invocation-owned storage so callers may use arrays and other temporary iterators.